@@ -751,10 +751,15 @@ H5T__vlen_reclaim(void *elem, const H5T_t *dt, H5T_vlen_alloc_info_t *alloc_info
             }
             else if (dt->shared->u.vlen.type == H5T_VLEN_STRING) {
                 
+                char *s;
+
+                
+                H5MM_memcpy(&s, elem, sizeof(char *));
+
                 if (free_func != NULL)
-                    (*free_func)(*(char **)elem, free_info);
+                    (*free_func)(s, free_info);
                 else
-                    free(*(char **)elem);
+                    free(s);
             }
             else {
                 assert(0 && "Invalid VL type");
